zmq_rpc
=======

0mq RPC calls implemented with pyzmq; part of the `zmq_rpc`_ project.

.. _zmq_rpc: https://bitbucket.org/xcg/zmq_rpc


Installing
----------

Install from pip::

    $ pip install zmq_rpc
